@@ -15,11 +15,11 @@ def close_json(paths_dict,options):
     outfile.close()
     return
 
-def open_netcdf(options):
+def open_netcdf(options,project_drs):
     infile=netCDF4.Dataset(options.in_diagnostic_netcdf_file,'r')
     paths_dict=dict()
     paths_dict['header']=dict()
-    for att in infile.ncattrs():
+    for att in project_drs.header_desc:
         paths_dict['header'][att]=json.loads(infile.getncattr(att))
     infile.close()
     return paths_dict
